@@ -24,6 +24,7 @@
 
 #include <RcppArmadillo.h>
 #include "sampler.h"
+#include "../inst/include/factorstochvol.h"
 
 using namespace Rcpp;
 
@@ -40,40 +41,11 @@ double rgig1(double lambda, double chi, double psi) {
 
 double do_rgig1(double lambda, double chi, double psi) {
 
-  if ( !(R_FINITE(lambda) && R_FINITE(chi) && R_FINITE(psi)) ||
-       (chi <  0. || psi < 0.)      ||
-       (chi == 0. && lambda <= 0.) ||
-       (psi == 0. && lambda >= 0.) ) {
-    ::Rf_error("invalid parameters for GIG distribution: lambda=%g, chi=%g, psi=%g",
-               lambda, chi, psi);
-  }
-
   double res;
-  // circumvent GIGrvg in these cases
-  if (chi < 10 * DBL_EPSILON) {
-    /* special cases which are basically Gamma and Inverse Gamma distribution */
-    if (lambda > 0.0) {
-      res = R::rgamma(lambda, 2.0/psi);
-    }
-    else {
-      res = 1.0/R::rgamma(-lambda, 2.0/chi); // fixed
-    }
-  }
-
-  else if (psi < 10 * DBL_EPSILON) {
-    /* special cases which are basically Gamma and Inverse Gamma distribution */
-    if (lambda > 0.0) {
-      res = R::rgamma(lambda, 2.0/psi);  // fixed
-    }
-    else {
-      res = 1.0/R::rgamma(-lambda, 2.0/chi); // fixed
-    }
-
-  } else {
-    SEXP (*fun)(int, double, double, double) = NULL;
+  
+  SEXP (*fun)(int, double, double, double) = NULL;
   if (!fun) fun = (SEXP(*)(int, double, double, double)) R_GetCCallable("GIGrvg", "do_rgig");
-    res = as<double>(fun(1, lambda, chi, psi));
-  }
+  res = as<double>(fun(1, lambda, chi, psi)); 
 
   return res;
 
